netapp_ontap.models.sql_on_smb API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.sql_on_smb`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SqlOnSmbSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SqlOnSmb object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access: SqlOnSmbAccess GET POST`

    The access field of the sql_on_smb.

  `db: SqlOnSanDb GET POST PATCH`

    The db field of the sql_on_smb.

  `log: SqlOnSanLog GET POST PATCH`

    The log field of the sql_on_smb.

  `protection_type: MongoDbOnSanProtectionType GET POST PATCH`

    The protection_type field of the sql_on_smb.

  `server_cores_count: Size GET POST`

    The number of server cores for the DB.

  `temp_db: SqlOnSanTempDb GET POST PATCH`

    The temp_db field of the sql_on_smb.